summaryrefslogtreecommitdiffstats
path: root/lib/VMCore/ValueSymbolTable.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/VMCore/ValueSymbolTable.cpp')
-rw-r--r--lib/VMCore/ValueSymbolTable.cpp68
1 files changed, 26 insertions, 42 deletions
diff --git a/lib/VMCore/ValueSymbolTable.cpp b/lib/VMCore/ValueSymbolTable.cpp
index eee18a1..7765a98 100644
--- a/lib/VMCore/ValueSymbolTable.cpp
+++ b/lib/VMCore/ValueSymbolTable.cpp
@@ -17,36 +17,20 @@
#include "llvm/ValueSymbolTable.h"
#include "llvm/ADT/SmallString.h"
#include "llvm/Support/Debug.h"
+#include "llvm/Support/raw_ostream.h"
using namespace llvm;
// Class destructor
ValueSymbolTable::~ValueSymbolTable() {
#ifndef NDEBUG // Only do this in -g mode...
for (iterator VI = vmap.begin(), VE = vmap.end(); VI != VE; ++VI)
- cerr << "Value still in symbol table! Type = '"
- << VI->getValue()->getType()->getDescription() << "' Name = '"
- << VI->getKeyData() << "'\n";
+ errs() << "Value still in symbol table! Type = '"
+ << VI->getValue()->getType()->getDescription() << "' Name = '"
+ << VI->getKeyData() << "'\n";
assert(vmap.empty() && "Values remain in symbol table!");
#endif
}
-// lookup a value - Returns null on failure...
-//
-Value *ValueSymbolTable::lookup(const std::string &Name) const {
- const_iterator VI = vmap.find(Name.data(), Name.data() + Name.size());
- if (VI != vmap.end()) // We found the symbol
- return VI->getValue();
- return 0;
-}
-
-Value *ValueSymbolTable::lookup(const char *NameBegin,
- const char *NameEnd) const {
- const_iterator VI = vmap.find(NameBegin, NameEnd);
- if (VI != vmap.end()) // We found the symbol
- return VI->getValue();
- return 0;
-}
-
// Insert a value into the symbol table with the specified name...
//
void ValueSymbolTable::reinsertValue(Value* V) {
@@ -54,37 +38,38 @@ void ValueSymbolTable::reinsertValue(Value* V) {
// Try inserting the name, assuming it won't conflict.
if (vmap.insert(V->Name)) {
- //DOUT << " Inserted value: " << V->Name << ": " << *V << "\n";
+ //DEBUG(errs() << " Inserted value: " << V->Name << ": " << *V << "\n");
return;
}
// Otherwise, there is a naming conflict. Rename this value.
- SmallString<128> UniqueName(V->getNameStart(), V->getNameEnd());
+ SmallString<256> UniqueName(V->getName().begin(), V->getName().end());
// The name is too already used, just free it so we can allocate a new name.
V->Name->Destroy();
unsigned BaseSize = UniqueName.size();
while (1) {
- // Trim any suffix off.
+ // Trim any suffix off and append the next number.
UniqueName.resize(BaseSize);
- UniqueName.append_uint_32(++LastUnique);
+ raw_svector_ostream(UniqueName) << ++LastUnique;
+
// Try insert the vmap entry with this suffix.
ValueName &NewName =
- vmap.GetOrCreateValue(UniqueName.data(),
- UniqueName.data() + UniqueName.size());
+ vmap.GetOrCreateValue(StringRef(UniqueName.data(),
+ UniqueName.size()));
if (NewName.getValue() == 0) {
// Newly inserted name. Success!
NewName.setValue(V);
V->Name = &NewName;
- //DEBUG(DOUT << " Inserted value: " << UniqueName << ": " << *V << "\n");
+ //DEBUG(errs() << " Inserted value: " << UniqueName << ": " << *V << "\n");
return;
}
}
}
void ValueSymbolTable::removeValueName(ValueName *V) {
- //DEBUG(DOUT << " Removing Value: " << V->getKeyData() << "\n");
+ //DEBUG(errs() << " Removing Value: " << V->getKeyData() << "\n");
// Remove the value from the symbol table.
vmap.remove(V);
}
@@ -92,33 +77,32 @@ void ValueSymbolTable::removeValueName(ValueName *V) {
/// createValueName - This method attempts to create a value name and insert
/// it into the symbol table with the specified name. If it conflicts, it
/// auto-renames the name and returns that instead.
-ValueName *ValueSymbolTable::createValueName(const char *NameStart,
- unsigned NameLen, Value *V) {
+ValueName *ValueSymbolTable::createValueName(const StringRef &Name, Value *V) {
// In the common case, the name is not already in the symbol table.
- ValueName &Entry = vmap.GetOrCreateValue(NameStart, NameStart+NameLen);
+ ValueName &Entry = vmap.GetOrCreateValue(Name);
if (Entry.getValue() == 0) {
Entry.setValue(V);
//DEBUG(DOUT << " Inserted value: " << Entry.getKeyData() << ": "
// << *V << "\n");
return &Entry;
}
// Otherwise, there is a naming conflict. Rename this value.
- SmallString<128> UniqueName(NameStart, NameStart+NameLen);
+ SmallString<128> UniqueName(Name.begin(), Name.end());
while (1) {
- // Trim any suffix off.
- UniqueName.resize(NameLen);
- UniqueName.append_uint_32(++LastUnique);
+ // Trim any suffix off and append the next number.
+ UniqueName.resize(Name.size());
+ raw_svector_ostream(UniqueName) << ++LastUnique;
// Try insert the vmap entry with this suffix.
ValueName &NewName =
- vmap.GetOrCreateValue(UniqueName.data(),
- UniqueName.data() + UniqueName.size());
+ vmap.GetOrCreateValue(StringRef(UniqueName.data(),
+ UniqueName.size()));
if (NewName.getValue() == 0) {
// Newly inserted name. Success!
NewName.setValue(V);
- //DEBUG(DOUT << " Inserted value: " << UniqueName << ": " << *V << "\n");
+ //DEBUG(errs() << " Inserted value: " << UniqueName << ": " << *V << "\n");
return &NewName;
}
}
@@ -128,10 +112,10 @@ ValueName *ValueSymbolTable::createValueName(const char *NameStart,
// dump - print out the symbol table
//
void ValueSymbolTable::dump() const {
- //DOUT << "ValueSymbolTable:\n";
+ //DEBUG(errs() << "ValueSymbolTable:\n");
for (const_iterator I = begin(), E = end(); I != E; ++I) {
- //DOUT << " '" << I->getKeyData() << "' = ";
+ //DEBUG(errs() << " '" << I->getKeyData() << "' = ");
I->getValue()->dump();
- //DOUT << "\n";
+ //DEBUG(errs() << "\n");
}
}
OpenPOWER on IntegriCloud
@@ -92,33 +77,32 @@ void ValueSymbolTable::removeValueName(ValueName *V) {
if (Entry.getValue() == 0) {
Entry.setValue(V);
- //DEBUG(DOUT << " Inserted value: " << Entry.getKeyData() << ": "
+ //DEBUG(errs() << " Inserted value: " << Entry.getKeyData() << ": "
// << *V << "\n");
return &Entry;